# Hurry Curry! - a game about cooking
# Copyright (C) 2025 Hurry Curry! contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, version 3 of the License only.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
class_name Cuttable
extends GenericItem

var cut: CPUParticles3D = load("res://map/items/cut.tscn").instantiate()

func _init(owned_by_: Node3D, scene: PackedScene, color: Color, height_: float = height):
	super(owned_by_, scene, height_)
	base.add_child(cut)
	cut.color = color

func progress(position_: float, speed: float, warn: bool):
	super(position_, speed, warn)
	cut.emitting = speed > 0
